@@ -6,6 +6,9 @@ from typing import Tuple, Deque, List, Final, Optional
 from spacepackets.log import get_console_logger
 
 SPACE_PACKET_HEADER_SIZE: Final = 6
+SEQ_FLAG_MASK = 0xC000
+APID_MASK = 0x7FF
+PACKET_ID_MASK = 0x1FFF
 
 
 class PacketTypes(enum.IntEnum):
@@ -38,6 +41,16 @@ class PacketSeqCtrl:
     def raw(self) -> int:
         return self.seq_flags << 14 | self.seq_count
 
+    @classmethod
+    def empty(cls):
+        return cls(seq_flags=SequenceFlags.CONTINUATION_SEGMENT, seq_count=0)
+
+    @classmethod
+    def from_raw(cls, raw: int):
+        return cls(
+            seq_flags=SequenceFlags((raw >> 14) & 0b11), seq_count=raw & ~SEQ_FLAG_MASK
+        )
+
 
 class PacketId:
     def __init__(self, ptype: PacketTypes, sec_header_flag: bool, apid: int):
@@ -49,6 +62,10 @@ class PacketId:
         self.sec_header_flag = sec_header_flag
         self.apid = apid
 
+    @classmethod
+    def empty(cls):
+        return cls(ptype=PacketTypes.TM, sec_header_flag=False, apid=0)
+
     def __repr__(self):
         return (
             f"{self.__class__.__name__}(ptype={self.ptype!r}, "
@@ -58,13 +75,19 @@ class PacketId:
     def raw(self) -> int:
         return self.ptype << 12 | self.sec_header_flag << 11 | self.apid
 
+    @classmethod
+    def from_raw(cls, raw: int) -> PacketId:
+        return cls(
+            ptype=PacketTypes((raw >> 12) & 0b1),
+            sec_header_flag=bool(raw >> 11 & 0b1),
+            apid=raw & APID_MASK,
+        )
+
 
 class SpacePacketHeader:
     """This class encapsulates the space packet header.
     Packet reference: Blue Book CCSDS 133.0-B-2"""
 
-    SEQ_FLAG_MASK = 0xC000
-
     def __init__(
         self,
         packet_type: PacketTypes,
@@ -183,8 +206,8 @@ class SpacePacketHeader:
         secondary_header_flag = (space_packet_raw[0] >> 3) & 0b1
         apid = ((space_packet_raw[0] & 0b111) << 8) | space_packet_raw[1]
         psc = struct.unpack("!H", space_packet_raw[2:4])[0]
-        sequence_flags = (psc & SpacePacketHeader.SEQ_FLAG_MASK) >> 14
-        ssc = psc & (~SpacePacketHeader.SEQ_FLAG_MASK)
+        sequence_flags = (psc & SEQ_FLAG_MASK) >> 14
+        ssc = psc & (~SEQ_FLAG_MASK)
         return SpacePacketHeader(
             packet_type=packet_type,
             apid=apid,
@@ -203,6 +226,9 @@ class SpacePacketHeader:
             f"seq_flags={self.seq_flags!r}"
         )
 
+    def __eq__(self, other: SpacePacketHeader):
+        return self.pack() == other.pack()
+
 
 class SpacePacket:
     """Generic CCSDS space packet which consists of the primary header and can optionally include
@@ -213,44 +239,57 @@ class SpacePacket:
 
     def __init__(
         self,
-        sph: SpacePacketHeader,
-        secondary_header: Optional[bytes],
-        user_data_field: Optional[bytes],
+        sp_header: SpacePacketHeader,
+        sec_header: Optional[bytes],
+        user_data: Optional[bytes],
     ):
-        self.sph = sph
-        self.sec_header = secondary_header
-        self.user_data_field = user_data_field
+        self.sp_header = sp_header
+        self.sec_header = sec_header
+        self.user_data = user_data
+
+    def __repr__(self):
+        return (
+            f"{self.__class__.__name__}(sp_header={self.sp_header!r}, "
+            f"sec_header={self.sec_header!r}, user_data={self.user_data!r})"
+        )
 
     def pack(self) -> bytearray:
         """Pack the raw byte representation of the space packet
         :raises ValueError: Mandatory fields were not supplied properly"""
-        packet = self.sph.pack()
-        if self.sph.sec_header_flag:
+        packet = self.sp_header.pack()
+        if self.sp_header.sec_header_flag:
             if self.sec_header is None:
                 raise ValueError(
                     "Secondary header flag is set but no secondary header was supplied"
                 )
             packet.extend(self.sec_header)
         else:
-            if self.user_data_field is None:
+            if self.user_data is None:
                 raise ValueError(
                     "Secondary header not present but no user data supplied"
                 )
-        if self.user_data_field is not None:
-            packet.extend(self.user_data_field)
+        if self.user_data is not None:
+            packet.extend(self.user_data)
         return packet
 
     @property
     def apid(self):
-        return self.sph.apid
+        return self.sp_header.apid
 
     @property
     def seq_count(self):
-        return self.sph.seq_count
+        return self.sp_header.seq_count
 
     @property
     def sec_header_flag(self):
-        return self.sph.sec_header_flag
+        return self.sp_header.sec_header_flag
+
+    def __eq__(self, other: SpacePacket):
+        return (
+            self.sp_header == other.sp_header
+            and self.sec_header == other.sec_header
+            and self.user_data == other.user_data
+        )
 
 
 def get_space_packet_id_bytes(
@@ -312,8 +351,7 @@ def parse_space_packets(
     analysis_queue: Deque[bytearray], packet_ids: Tuple[int]
 ) -> List[bytearray]:
     """Given a deque of bytearrays, parse for space packets. Any broken headers will be removed.
-    If a packet is detected and the
-    Any broken tail packets will be reinserted into the given deque
+    If a packet is detected and the broken tail packets will be reinserted into the given deque
     :param analysis_queue:
     :param packet_ids:
     :return:
@@ -333,8 +371,9 @@ def parse_space_packets(
         if current_idx + 6 >= len(concatenated_packets):
             break
         current_packet_id = (
-            concatenated_packets[current_idx] << 8
-        ) | concatenated_packets[current_idx + 1]
+            struct.unpack("!H", concatenated_packets[current_idx : current_idx + 2])[0]
+            & PACKET_ID_MASK
+        )
         if current_packet_id in packet_ids:
             result, current_idx = __handle_packet_id_match(
                 concatenated_packets=concatenated_packets,
@@ -356,10 +395,9 @@ def __handle_packet_id_match(
     current_idx: int,
     tm_list: List[bytearray],
 ) -> (int, int):
-    next_packet_len_field = (
-        concatenated_packets[current_idx + 4] << 8
-    ) | concatenated_packets[current_idx + 5]
-    total_packet_len = get_total_space_packet_len_from_len_field(next_packet_len_field)
+    total_packet_len = get_total_space_packet_len_from_len_field(
+        struct.unpack("!H", concatenated_packets[current_idx + 4 : current_idx + 6])[0]
+    )
     # Might be part of packet. Put back into analysis queue as whole
     if total_packet_len > len(concatenated_packets):
         analysis_queue.appendleft(concatenated_packets)
